<img src="https://img.shields.io/github/license/TralahM/tekmpesa"> <img src="https://img.shields.io/github/last-commit/TralahM/tekmpesa"> <img src="https://img.shields.io/github/contributors/TralahM/tekmpesa"> <img src="https://img.shields.io/github/issues-pr-raw/TralahM/tekmpesa?color=blue"> <img src="https://img.shields.io/github/issues-pr-closed-raw/TralahM/tekmpesa?color=red"> <img src="https://img.shields.io/github/issues-raw/TralahM/tekmpesa?color=green">
<img src="https://img.shields.io/github/issues-closed-raw/TralahM/tekmpesa?color=yellow"> <img src="https://img.shields.io/github/forks/TralahM/tekmpesa?label=Forks&style=social"> <img src="https://img.shields.io/github/forks/TralahM/tekmpesa?label=Forks&style=social"> <img src="https://img.shields.io/github/stars/TralahM/tekmpesa?style=social">
<img src="https://img.shields.io/github/watchers/TralahM/tekmpesa?label=Watch&style=social"> <img src="https://img.shields.io/github/downloads/TralahM/tekmpesa/total"> <img src="https://img.shields.io/github/repo-size/TralahM/tekmpesa"> <img src="https://img.shields.io/github/languages/count/TralahM/tekmpesa"> <img src="https://img.shields.io/github/v/tag/TralahM/tekmpesa"> <img src="https://img.shields.io/readthedocs/tekmpesa"> <img src="https://img.shields.io/pypi/v/tekmpesa"> <img src="https://img.shields.io/pypi/pyversions/tekmpesa"> <img src="https://img.shields.io/pypi/wheel/tekmpesa"> <img src="https://img.shields.io/pypi/status/tekmpesa?label=pypi%20status"> <img src="https://img.shields.io/pypi/format/tekmpesa?label=pypi%20format">

# tekmpesa
> All Mpesa APIs for All 8 Countries

---

### Table of Contents
- [QuickStart](#QuickStart)
- [Documentation/Usage](#Documentation)
- [Contributing](#Contributing)
- [Credits](#Credits)

---
## QuickStart
#### Installation

```
pip install tekmpesa
```
#### From Source
```
git clone https://github.com/TralahM/tekmpesa
cd tekmpesa

python setup.py bdist_wheel
pip install -e .

```
---

## Documentation

[![Documentation](https://img.shields.io/badge/Docs-tekmpesa-blue.svg?style=for-the-badge)](https://tekmpesa.readthedocs.io)


#### API Reference

---
## Contributing

---

## Credits
[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-black.svg?style=for-the-badge&logo=github)](https://github.com/TralahTek)
[![TralahM](https://img.shields.io/badge/Engineer-TralahM-blue.svg?style=for-the-badge&logo=github)](https://github.com/TralahM)
[![TralahM](https://img.shields.io/badge/Maintainer-TralahM-green.svg?style=for-the-badge&logo=github)](https://github.com/TralahM)



[![](https://img.shields.io/badge/Github-TralahM-green?style=for-the-badge&logo=github)](https://github.com/TralahM)
[![](https://img.shields.io/badge/Twitter-%40tralahtek-blue?style=for-the-badge&logo=twitter)](https://twitter.com/TralahM)
[![TralahM](https://img.shields.io/badge/Kaggle-TralahM-purple.svg?style=for-the-badge&logo=kaggle)](https://kaggle.com/TralahM)
[![TralahM](https://img.shields.io/badge/LinkedIn-TralahM-white.svg?style=for-the-badge&logo=linkedin)](https://linkedin.com/in/TralahM)


[![Blog](https://img.shields.io/badge/Blog-tralahm.tralahtek.com-blue.svg?style=for-the-badge&logo=rss)](https://tralahm.tralahtek.com)

[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-cyan.svg?style=for-the-badge)](https://org.tralahtek.com)
---